@@ -12,9 +12,9 @@ class Visualizer(QMainWindow):
     # than a few optional arguments, but multiple different objects with fewer
     # (and more relevant) arguments each. Eg maybe expose Renderer, which would
     # take speeds and start_speed.
-    def __init__(self, beatmap_info, replays=[], events=[], library=None, \
-        speeds=[0.1, 0.25, 0.5, 0.75, 1.0, 1.5, 3.0, 5.0, 10.0], start_speed=1,\
-        paint_info=True, statistic_functions=[], snaps_args={}):
+    def __init__(self, beatmap_info, replays=[], events=[], library=None,
+        speeds=[0.05, 0.1, 0.25, 0.5, 0.75, 1.0, 1.5, 3.0, 5.0, 10.0],
+        start_speed=1, paint_info=True, statistic_functions=[], snaps_args={}):
         super().__init__()
 
         self.beatmap_info = beatmap_info
@@ -29,18 +29,22 @@ class Visualizer(QMainWindow):
 
         self.setAutoFillBackground(True)
         self.setWindowTitle("Visualizer")
-        self.interface = Interface(beatmap_info, replays, events, library, \
+        self.interface = Interface(beatmap_info, replays, events, library,
             speeds, start_speed, paint_info, statistic_functions, snaps_args)
+        self.interface.renderer.loaded_signal.connect(self.on_load)
         self.setCentralWidget(self.interface)
 
         QShortcut(Qt.Key_Space, self, self.interface.toggle_pause)
-        QShortcut(Qt.Key_Right, self, lambda: self.interface.change_frame(reverse=False))
-        QShortcut(Qt.Key_Left, self, lambda: self.interface.change_frame(reverse=True))
+        QShortcut(Qt.Key_Right, self,
+            lambda: self.interface.change_frame(reverse=False))
+        QShortcut(Qt.Key_Left, self,
+            lambda: self.interface.change_frame(reverse=True))
         QShortcut(Qt.CTRL + Qt.Key_Right, self, self.interface.play_normal)
         QShortcut(Qt.CTRL + Qt.Key_Left, self, self.interface.play_reverse)
         QShortcut(Qt.Key_Up, self, self.interface.increase_speed)
         QShortcut(Qt.Key_Down, self, self.interface.lower_speed)
-        QShortcut(Qt.CTRL + Qt.Key_F11, self, self.interface.renderer.toggle_frametime)
+        QShortcut(Qt.CTRL + Qt.Key_F11, self,
+             self.interface.renderer.toggle_frametime)
         QShortcut(QKeySequence.FullScreen, self, self.toggle_fullscreen)
         QShortcut(Qt.Key_F, self, self.toggle_fullscreen)
         QShortcut(Qt.ALT + Qt.Key_Return, self, self.toggle_fullscreen)
@@ -54,7 +58,7 @@ class Visualizer(QMainWindow):
         # not meant to be changed to increase the window size (same with width).
         from .renderer import (GAMEPLAY_WIDTH, GAMEPLAY_HEIGHT,
             GAMEPLAY_PADDING_WIDTH, GAMEPLAY_PADDING_HEIGHT)
-        self.resize((GAMEPLAY_WIDTH + GAMEPLAY_PADDING_WIDTH * 2) * 1.2, \
+        self.resize((GAMEPLAY_WIDTH + GAMEPLAY_PADDING_WIDTH * 2) * 1.2,
                     (GAMEPLAY_HEIGHT + GAMEPLAY_PADDING_HEIGHT * 2) * 1.2)
 
     def closeEvent(self, event):
@@ -99,6 +103,14 @@ class Visualizer(QMainWindow):
     def save_as_image(self):
         return self.grab().toImage()
 
+    def on_load(self):
+        """
+        Will be called when the visualizer has completely loaded (including
+        processing the beatmap, replays, sliders, and anything else) and is
+        ready to display gameplay.
+        """
+        pass
+
     # TODO remove in circlevis 2.0.0
     force_pause = pause
     force_unpause = unpause
@@ -107,9 +119,9 @@ class VisualizerApp(QApplication):
     """
     ``speeds`` must contain ``start_speed``, ``1``, ``0.75``, and ``1.5``.
     """
-    def __init__(self, beatmap_info, replays=[], events=[], library=None, \
-        speeds=[0.05, 0.1, 0.25, 0.5, 0.75, 1.0, 1.5, 3.0, 5.0, 10.0], start_speed=1,\
-        paint_info=True, statistic_functions=[], snaps_args={}):
+    def __init__(self, beatmap_info, replays=[], events=[], library=None,
+        speeds=[0.05, 0.1, 0.25, 0.5, 0.75, 1.0, 1.5, 3.0, 5.0, 10.0],
+        start_speed=1, paint_info=True, statistic_functions=[], snaps_args={}):
         super().__init__([])
         self.setStyle("Fusion")
         self.setApplicationName("Circlevis")
@@ -133,9 +145,10 @@ class VisualizerApp(QApplication):
         # we can't create this in ``__init__`` because we can't instantiate a
         # ``QWidget`` before a ``QApplication``, so delay until here, which is
         # all it's necessary for.
-        self.visualizer = Visualizer(self.beatmap_info, self.replays, \
-            self.events, self.library, self.speeds, self.start_speed, \
+        self.visualizer = Visualizer(self.beatmap_info, self.replays,
+            self.events, self.library, self.speeds, self.start_speed,
             self.paint_info, self.statistic_functions, self.snaps_args)
+        self.interface.renderer.loaded_signal.connect(self.on_load)
         self.visualizer.show()
         super().exec()
 
@@ -180,6 +193,14 @@ class VisualizerApp(QApplication):
     def save_as_image(self):
         return self.visualizer.grab().toImage()
 
+    def on_load(self):
+        """
+        Will be called when the visualizer has completely loaded (including
+        processing the beatmap, replays, sliders, and anything else) and is
+        ready to display gameplay.
+        """
+        pass
+
     # TODO remove in circlevis 2.0.0
     force_pause = pause
     force_unpause = unpause
